function [lof,Irep]=shiftlof(Iexp,c,v,E,deltaE);

%**************************************************************************
%
% shiftlof program, by J.M. Daz-Cruz, May 2007, Last revised October 2007
%
% Requires shiftcalc function
%
% Computes the overall lack of fit (lof, in %) and the reproduced matrix 
% (Irep) after both peak movement correction and MCR-ALS analysis from the 
% potential (E) and potential shift (deltaE) matrices, the experimental
% matrix (Iexp) and the concentration matrix (c) and the pure signals
% matrix (v), both obtained by MCR-ALS
%
% Syntax:   [lof,Irep]=shiftlof(Iexp,c,v,E,deltaE);
%
%**************************************************************************

%checking dimensions 

[nconc,npot]=size(Iexp);
if nconc>npot, Iexp=Iexp'; [nconc,npot]=size(Iexp);end

[nconc,nspec]=size(deltaE);
if nconc<nspec, deltaE=deltaE', [nconc,nspec]=size(deltaE);end

[npot,nothing]=size(E);
if npot<nothing, E=E'; [npot,nothing]=size(E);end

[nconc2,nspec2]=size(c);
if nconc2<nspec2, c=c'; [nconc2,nspec2]=size(c);end
if nconc2~=nconc; error('c and delta E have different number of measurements');end
if nspec2~=nspec; error('c and deltaE have different number of species');end

[npot2,nspec3]=size(v);
if npot2<nspec3, v=v'; [npot2,nspec3]=size(v); end
if npot2~=npot; error('v and E have different number of potentials');end
if nspec3~=nspec; error('v and c have different number of species');end

%normalization of deltaE to units of column (delta matrix)

deltaErange=E(1,1)-E(npot,1); 
delta=deltaE./deltaErange;

%determination of the components/species moved (isshift matrix)

isshift=zeros(1,nspec);

for i=1:nspec, 
	
	if delta(:,i)==zeros(nconc,1), isshift(1,i)=0;
	else isshift(1,i)=1;
	end
	
end

% MCR-ALS + shiftfit reproduced data matrix Irep

Irep=zeros(nconc,npot);

for i=1:nconc,
	
cv=[isshift;c(i,:);v];

[Irep(i,:)]=shiftcalc(delta(i,:),cv);

end

%comparison of Iexp and Irep

sumdif=0;sum=0;

for i=1:nconc,
	for j=1:npot,
		sumdif=sumdif+(Irep(i,j)-Iexp(i,j))^2;
		sum=sum+(Iexp(i,j))^2;
	end
end

lof=((sumdif/sum)^0.5)*100;
lofs=num2str(lof);

disp(' ');disp(['lack of fit (%) = ',lofs]);disp(' ');

isplot=input('do you want a plot (1/0) ?  ');

if isplot==1,
	subplot(2,1,1); plot(-E,Iexp,'k');xlabel('-E / V');ylabel('I / A');title('Experimental Matrix');
	subplot(2,1,2); plot(-E,Irep,'k');xlabel('-E / V');ylabel('I / A');title('Overall Reproduced Matrix');
end


